* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [OData Integration](https://help.sap.com/docs/leanix/ea/odata-integration)
  * OData Integration Update: Translation Corrections (…
